==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/sv.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} är tillgänglig. Få mer information om hur du uppdaterar.",
    "Could not start updater, please try the manual update" : "Kunde inte starta uppdateraren, vänligen försök uppdatera manuellt",
    "Apps with available updates" : "Appar med tillgängliga uppdateringar",
    "Open updater" : "Öppna uppdateraren",
    "Download now" : "Ladda ned nu",
    "Your version is up to date." : "Din version är uppdaterad.",
    "The update check is not yet finished. Please refresh the page." : "Uppdateringskontrollen är inte färdig ännu. Var god uppdatera sidan.",
    "A non-default update server is in use to be checked for updates:" : "En icke-standard updateringsserver används för att kolla efter uppdateringar:",
    "Update channel:" : "Uppdateringskanal:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Du kan alltid uppdatera till en nyare version / experimentell kanal. Men du kan aldrig nedgradera till en mer stabil kanal.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Notera att när en ny version släppts kan det ta lite tid innan den dyker upp här. Vi rullar ut nya versioner till våra användare vid utspridda tillfällen och hoppar ibland över versioner när problem hittas.",
    "Notify members of the following groups about available updates:" : "Notifiera medlemmar i följande grupper om tillgängliga uppdateraingar:",
    "Only notification for app updates are available." : "Endast notifikation för app-uppdateringar är tillgängliga.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Den valda uppdateringskanalen gör dedikerade notiser för servern förlegade.",
    "The selected update channel does not support updates of the server." : "Den valda uppdateringskanalen stödjer inte uppdateringar för servern.",
    "Update notifications" : "Uppdateringsnotifikationer",
    "Channel updated" : "Uppdateringskanal uppdaterad",
    "The update server could not be reached since %d days to check for new updates." : "Uppdateringsservern kunde inte nås. Senaste kontakt för %d dagar sedan.",
    "Please check the Nextcloud and server log files for errors." : "Vänligen kontrollera ditt moln och dess serverloggar för felmeddelanden.",
    "Update to %1$s is available." : "Uppdatering till %1$s är tillgänglig.",
    "Update for %1$s to version %2$s is available." : "Uppdatering för %1$s till version %2$s är tillgänglig.",
    "Update for {app} to version %s is available." : "Uppdatering för {app} till version %s är tillgänglig.",
    "Update notification" : "Uppdatera notifikation",
    "A new version is available: %s" : "En ny version är tillgänglig: %s",
    "Checked on %s" : "Senast kontrollerad %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/sv.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} är tillgänglig. Få mer information om hur du uppdaterar.",
    "Update notifications" : "Uppdateringsnotifikationer",
    "Channel updated" : "Uppdateringskanal uppdaterad",
    "The update server could not be reached since %d days to check for new updates." : "Uppdateringsservern kunde inte nås. Senaste kontakt för %d dagar sedan.",
    "Please check the Nextcloud and server log files for errors." : "Vänligen kontrollera ditt moln och dess serverloggar för felmeddelanden.",
    "Update to %1$s is available." : "Uppdatering till %1$s är tillgänglig.",
    "Update for %1$s to version %2$s is available." : "Uppdatering för %1$s till version %2$s är tillgänglig.",
    "Update for {app} to version %s is available." : "Uppdatering för {app} till version %s är tillgänglig.",
    "Update notification" : "Uppdatera notifikation",
    "Apps with available updates" : "Appar med tillgängliga uppdateringar",
    "Open updater" : "Öppna uppdateraren",
    "Download now" : "Ladda ned nu",
    "The update check is not yet finished. Please refresh the page." : "Uppdateringskontrollen är inte färdig ännu. Var god uppdatera sidan.",
    "Your version is up to date." : "Din version är uppdaterad.",
    "A non-default update server is in use to be checked for updates:" : "En icke-standard updateringsserver används för att kolla efter uppdateringar:",
    "Update channel:" : "Uppdateringskanal:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Du kan alltid uppdatera till en nyare version / experimentell kanal. Men du kan aldrig nedgradera till en mer stabil kanal.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Notera att när en ny version släppts kan det ta lite tid innan den dyker upp här. Vi rullar ut nya versioner till våra användare vid utspridda tillfällen och hoppar ibland över versioner när problem hittas.",
    "Notify members of the following groups about available updates:" : "Notifiera medlemmar i följande grupper om tillgängliga uppdateraingar:",
    "Only notification for app updates are available." : "Endast notifikation för app-uppdateringar är tillgängliga.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Den valda uppdateringskanalen gör dedikerade notiser för servern förlegade.",
    "The selected update channel does not support updates of the server." : "Den valda uppdateringskanalen stödjer inte uppdateringar för servern.",
    "A new version is available: <strong>{newVersionString}</strong>" : "En ny version är tillgänglig: <strong>{newVersionString}</strong>",
    "Checking apps for compatible updates" : "Kontrollera appar för kompatibla uppdateringar",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Se till att din config.php inte ställer in <samp>appstoreenabled</samp> till falsk.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Alla</strong> appar har en uppdatering för den här versionen tillgänglig",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>stable</strong> är den senaste stabila versionen. Den är lämplig för regelbunden användning och kommer alltid att uppdatera till den senaste mer omfattande versionen.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> appen har ingen uppdatering för den här versionen tillgänglig","<strong>%n</strong> appar har inga uppdateringar för den här versionen tillgänglig"],
    "Could not start updater, please try the manual update" : "Kunde inte starta uppdateraren, vänligen försök uppdatera manuellt",
    "A new version is available: %s" : "En ny version är tillgänglig: %s",
    "Checked on %s" : "Senast kontrollerad %s"
},
"nplurals=2; plural=(n != 1);");
